@@ -27,7 +27,7 @@
 
 ;;; Code:
 
-(require 'gptel-request)
+(eval-and-compile (require 'gptel-request))
 (require 'cl-lib)
 (require 'project)
 
@@ -364,8 +364,8 @@ afterwards."
        if (bufferp source) do           ;Buffers and buffer regions
        (mapc #'gptel-context-remove (plist-get spec :overlays))
        else do (gptel-context-remove source) ;files or other types
-       finally do (setq gptel-context nil)))
-    (when verbose (message "Removed all gptel context sources."))))
+       finally do (setq gptel-context nil))
+      (when verbose (message "Removed all gptel context sources.")))))
 
 ;;; Context wrap
 (defun gptel-context--make-overlay (start end &optional advance)
@@ -840,7 +840,7 @@ If non-nil, indicates backward movement.")
   ;; FIXME(context): This should run in the buffer from which the context
   ;; inspection buffer was visited.
   ;; Update contexts and revert buffer (#482)
-  (setq gptel-context (gptel-context--collect))
+  (setq gptel-context (nreverse (gptel-context--collect)))
   (gptel-context-quit))
 
 (provide 'gptel-context)
